@@ -243,10 +243,11 @@ class Eqonomize : public QMainWindow {
 		QAction *ActionImportCSV, *ActionImportQIF, *ActionImportEQZ, *ActionExportQIF;
 		QAction *ActionConvertCurrencies, *ActionUpdateExchangeRates;
 		QAction *ActionExtraProperties, *ActionUseExchangeRateForTransactionDate, *ActionSetBudgetPeriod, *ActionSetScheduleConfirmationTime, *AIPCurrentMonth, *AIPCurrentYear, *AIPCurrentWholeMonth, *AIPCurrentWholeYear, *AIPRememberLastDates, *ABFDaily, *ABFWeekly, *ABFFortnightly, *ABFMonthly, *ABFNever, *ACSTime[11];
-		QAction *ActionSetMainCurrency, *ActionSyncSettings, *ActionSelectFont;
+		QAction *ActionSetMainCurrency, *ActionSyncSettings, *ActionSelectFont, *ActionDarkMode;
 		QActionGroup *ActionSelectInitialPeriod, *ActionSelectBackupFrequency, *ActionSelectLang;
 		QAction *ActionHelp, *ActionWhatsThis, *ActionReportBug, *ActionAbout, *ActionAboutQt;
 		QAction *ActionNewTag, *ActionRenameTag, *ActionRemoveTag;
+		QAction *ActionRightAlignValues, *SeparatorRightAlignValues;
 
 		TagMenu *tagMenu;
 		QMenu *linkMenu;
@@ -257,7 +258,7 @@ class Eqonomize : public QMainWindow {
 		void updateRecentFiles(QString filePath = QString());
 		void saveOptions();
 		void closeEvent(QCloseEvent *event);
-
+		void updatePalette(bool);
 		void dragEnterEvent(QDragEnterEvent *event);
 		void dropEvent(QDropEvent *event);
 
@@ -269,6 +270,7 @@ class Eqonomize : public QMainWindow {
 		QDate prev_cur_date;
 		bool partial_budget;
 		bool b_extra;
+		bool right_align_values;
 		QLocalSocket *socket;
 		QLocalServer *server;
 		QString cr_tmp_file;
@@ -361,6 +363,7 @@ class Eqonomize : public QMainWindow {
 		void setScheduleConfirmationTime();
 
 		void selectFont();
+		void setDarkMode(bool);
 
 		void showFilter();
 
@@ -550,6 +553,8 @@ class Eqonomize : public QMainWindow {
 		void transactionModified(Transactions*, Transactions*);
 		void transactionRemoved(Transactions*, Transactions* = NULL, bool permanent = false);
 
+		void valueAlignmentUpdated(bool);
+
 		void filterAccounts();
 
 	signals:
