@@ -67,6 +67,9 @@ extern QString last_document_directory;
 
 ImportCSVDialog::ImportCSVDialog(bool extra_parameters, Budget *budg, QWidget *parent) : QWizard(parent), b_extra(extra_parameters), budget(budg) {
 
+	QSettings settings;
+	if(settings.value("GeneralOptions/darkMode", false).toBool()) setWizardStyle(QWizard::ClassicStyle);
+
 	setWindowTitle(tr("Import CSV file"));
 	setModal(true);
 
@@ -108,9 +111,7 @@ ImportCSVDialog::ImportCSVDialog(bool extra_parameters, Budget *budg, QWidget *p
 	presetCombo = new QComboBox();
 	presetCombo->setMinimumContentsLength(20);
 	presetCombo->setEditable(false);
-	QSettings settings;
-	settings.beginGroup("GeneralOptions");
-	presets = settings.value("CSVPresets").toMap();
+	presets = settings.value("GeneralOptions/CSVPresets").toMap();
 	for(QMap<QString, QVariant>::const_iterator it = presets.constBegin(); it != presets.constEnd(); ++it) {
 		presetCombo->addItem(it.key());
 	}
@@ -370,6 +371,14 @@ ImportCSVDialog::ImportCSVDialog(bool extra_parameters, Budget *budg, QWidget *p
 	layout3->addLayout(layout3_cm, row, 0, 1, 5);
 	row++;
 
+	QHBoxLayout *layout3_id = new QHBoxLayout();
+	layout3_id->addStretch(1);
+	ignoreDuplicateTransactionsButton = new QCheckBox(tr("Ignore duplicate transactions"), page3);
+	ignoreDuplicateTransactionsButton->setChecked(false);
+	layout3_id->addWidget(ignoreDuplicateTransactionsButton);
+	layout3->addLayout(layout3_id, row, 0, 1, 5);
+	row++;
+
 	QHBoxLayout *layoutPreset2 = new QHBoxLayout();
 	layoutPreset2->addStretch(1);
 	savePresetButton = new QPushButton(tr("Save as preset…"), page3);
@@ -444,7 +453,7 @@ void ImportCSVDialog::loadPreset(int index) {
 	s_preset = presetCombo->itemText(index);
 	if(!presets.contains(s_preset)) return;
 	QList<QVariant> preset = presets[s_preset].toList();
-	if(preset.count() < 26) return;
+	if(preset.count() < 4) return;
 	typeGroup->button(preset.at(0).toInt())->setChecked(true);
 	typeChanged(preset.at(0).toInt());
 	fileEdit->setText(preset.at(1).toString());
@@ -459,6 +468,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		delimiterEdit->setText(delimiter);
 	}
 	int i = 4;
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueDateButton->setChecked(true);
 		valueDateEdit->setDate(preset.at(i + 1).toDate());
@@ -467,6 +477,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		columnDateEdit->setValue(preset.at(i + 1).toInt());
 	}
 	i += 2;
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueDescriptionButton->setChecked(true);
 		valueDescriptionEdit->setText(preset.at(i + 1).toString());
@@ -475,6 +486,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		columnDescriptionEdit->setValue(preset.at(i + 1).toInt());
 	}
 	i += 2;
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueCostButton->setChecked(true);
 		valueCostEdit->setValue(preset.at(i + 1).toDouble());
@@ -483,6 +495,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		columnCostEdit->setValue(preset.at(i + 1).toInt());
 	}
 	i += 2;
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueValueButton->setChecked(true);
 		valueValueEdit->setValue(preset.at(i + 1).toDouble());
@@ -491,6 +504,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		columnValueEdit->setValue(preset.at(i + 1).toInt());
 	}
 	i += 2;
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueAC1Button->setChecked(true);
 		qlonglong id = preset.at(i + 1).toLongLong();
@@ -518,6 +532,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		columnAC1Edit->setValue(preset.at(i + 1).toInt());
 	}
 	i += 3;
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueAC2Button->setChecked(true);
 		qlonglong id = preset.at(i + 1).toLongLong();
@@ -535,6 +550,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		columnAC2Edit->setValue(preset.at(i + 1).toInt());
 	}
 	i += 2;
+	if(i >= preset.count()) return;
 	if(b_extra) {
 		if(preset.at(i).toBool()) {
 			valueQuantityButton->setChecked(true);
@@ -555,6 +571,7 @@ void ImportCSVDialog::loadPreset(int index) {
 	} else {
 		i += 4;
 	}
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueTagsButton->setChecked(true);
 		valueTagsEdit->setText(preset.at(i + 1).toString());
@@ -563,6 +580,7 @@ void ImportCSVDialog::loadPreset(int index) {
 		columnTagsEdit->setValue(preset.at(i + 1).toInt());
 	}
 	i += 2;
+	if(i >= preset.count()) return;
 	if(preset.at(i).toBool()) {
 		valueCommentsButton->setChecked(true);
 		valueCommentsEdit->setText(preset.at(i + 1).toString());
@@ -572,6 +590,8 @@ void ImportCSVDialog::loadPreset(int index) {
 	}
 	i += 2;
 	createMissingButton->setChecked(preset.at(i).toBool());
+	i++;
+	ignoreDuplicateTransactionsButton->setChecked(i < preset.count() && preset.at(i).toBool());
 }
 void ImportCSVDialog::savePreset() {
 	QDialog *dialog = new QDialog(this);
@@ -697,6 +717,7 @@ void ImportCSVDialog::savePreset() {
 			preset << columnCommentsEdit->value();
 		}
 		preset << createMissingButton->isChecked();
+		preset << ignoreDuplicateTransactionsButton->isChecked();
 		presets[s_preset] = preset;
 		if(presetEdit->currentIndex() >= 0) {
 			presetCombo->setCurrentIndex(presetEdit->currentIndex());
@@ -1225,6 +1246,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 		}
 	}
 	bool create_missing = createMissingButton->isChecked() && type != ALL_TYPES_ID;
+	bool ignore_duplicates = ignoreDuplicateTransactionsButton->isChecked();
 	QString description, comments, payee, tags;
 	double quantity = 1.0;
 	if(!test && description_c < 0) description = valueDescriptionEdit->text();
@@ -1297,6 +1319,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 	//bool had_data = false;
 	int successes = 0;
 	int failed = 0;
+	int duplicates = 0;
 	bool missing_columns = false, value_error = false, date_error = false;
 	bool AC1_empty = false, AC2_empty = false, AC1_missing = false, AC2_missing = false, AC_security = false, AC_balancing = false, AC_same = false;
 	bool AC1_category = (type == 0 || type == 1 || type == 3 || type == 4);
@@ -1737,7 +1760,11 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 					if(trans) {
 						trans->readTags(tags);
 						trans->setQuantity(quantity);
-						if(trans->date() > curdate) {
+						if(ignore_duplicates && budget->findDuplicateTransaction(trans)) {
+							duplicates++;
+							successes--;
+							delete trans;
+						} else if(trans->date() > curdate) {
 							trans->setTimestamp(datestamps.contains(QDate::currentDate()) ? datestamps[QDate::currentDate()] + 1 : DATE_TO_MSECS(QDate::currentDate()) / 1000);
 							datestamps[QDate::currentDate()] = trans->timestamp();
 							budget->addScheduledTransaction(new ScheduledTransaction(budget, trans, NULL));
@@ -1767,6 +1794,10 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 	} else {
 		info = tr("Unable to import any transactions.");
 	}
+	if(duplicates > 0) {
+		info += "\n";
+		info += tr("%n duplicate transaction(s) was ignored.", "", duplicates);
+	}
 	if(failed > 0) {
 		info += '\n';
 		info += tr("Failed to import %n data row(s).", "", failed);
@@ -1780,7 +1811,7 @@ bool ImportCSVDialog::import(bool test, csv_info *ci) {
 		if(AC_security) {details += "\n-"; details += tr("Cannot import security transactions (to/from security accounts).");}
 		if(AC_balancing) {details += "\n-"; details += tr("Balancing account wrongly used.", "Referring to the account used for adjustments of account balances.");}
 		if(AC_same) {details += "\n-"; details += tr("Same to and from account/category.");}
-	} else if(successes == 0) {
+	} else if(successes == 0 && duplicates == 0) {
 		info = tr("No data found.");
 	}
 	if(failed > 0 || successes == 0) {
